From dea284f5715c8efda8a450ca8fffee6d8e78e83a Mon Sep 17 00:00:00 2001
From: fantu <fantu@ispconfig3>
Date: Tue, 18 Nov 2008 16:43:38 -0500
Subject: [PATCH] Improved merge in language editor: - Remove of the file how not exists in master language - Fix the msg show when no file has been created, removed or modified
---
interface/web/sites/web_domain_list.php | 9 +++------
1 files changed, 3 insertions(+), 6 deletions(-)
diff --git a/interface/web/sites/web_domain_list.php b/interface/web/sites/web_domain_list.php
index edc7e7f..3520c28 100644
--- a/interface/web/sites/web_domain_list.php
+++ b/interface/web/sites/web_domain_list.php
@@ -41,16 +41,13 @@
* End Form configuration
******************************************/
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
- header("Location: ../index.php");
- exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
$app->uses('listform_actions');
// Limit the results to alias domains
-// $app->listform_actions->SQLExtWhere = "type = 'local'";
+$app->listform_actions->SQLExtWhere = "type = 'vhost'";
$app->listform_actions->onLoad();
--
Gitblit v1.9.1